@@ -1,5 +1,5 @@
 import traceback
-from typing import Awaitable, Callable, Optional, Union
+from typing import Awaitable, Callable, Dict, Optional, Union
 
 from ..events import KeyEventArguments, KeyboardAction, KeyboardKey, KeyboardModifiers, handle_event
 from .custom_view import CustomView
@@ -7,8 +7,8 @@ from .element import Element
 
 class KeyboardView(CustomView):
 
-    def __init__(self, on_key: Callable):
-        super().__init__('keyboard', __file__, activeJSEvents=['keydown', 'keyup', 'keypress'])
+    def __init__(self, on_key: Callable, repeating: bool):
+        super().__init__('keyboard', __file__, active_js_events=['keydown', 'keyup', 'keypress'], repeating=repeating)
         self.allowed_events = ['keyboardEvent']
         self.style = 'display: none'
         self.initialize(temp=False, on_keyboardEvent=on_key)
@@ -20,6 +20,7 @@ class Keyboard(Element):
                  *,
                  on_key: Optional[Union[Callable, Awaitable]] = None,
                  active: bool = True,
+                 repeating: bool = True,
                  ):
         """
         Keyboard
@@ -27,13 +28,14 @@ class Keyboard(Element):
         Adds global keyboard event tracking.
 
         :param handle_keys: callback to be executed when keyboard events occur.
-        :param active: boolean flag indicating whether the callback should be executed or not
+        :param active: boolean flag indicating whether the callback should be executed or not (default: True)
+        :param repeating: boolean flag indicating whether held keys should be sent repeatedly (default: True)
         """
-        super().__init__(KeyboardView(on_key=self.handle_key))
+        super().__init__(KeyboardView(on_key=self.handle_key, repeating=repeating))
         self.active = active
         self.key_handler = on_key
 
-    def handle_key(self, msg: dict):
+    def handle_key(self, msg: Dict):
         if not self.active:
             return
 
@@ -55,6 +57,7 @@ class Keyboard(Element):
                 code=msg.key_data.code,
                 location=msg.key_data.location,
             )
-            handle_event(self.key_handler, KeyEventArguments(sender=self, action=action, modifiers=modifiers, key=key))
+            arguments = KeyEventArguments(sender=self, action=action, modifiers=modifiers, key=key)
+            handle_event(self.key_handler, arguments, update=self.parent_view)
         except Exception:
             traceback.print_exc()
