@@ -1,9 +1,11 @@
 var scene;
 var camera;
 var orbitControls;
-var loader = new THREE.TextureLoader();
+var texture_loader = new THREE.TextureLoader();
+var stl_loader = new THREE.STLLoader();
 var objects = new Map();
 
+const None = null;
 const False = false;
 const True = true;
 
@@ -164,7 +166,7 @@ Vue.component("scene", {
         geometry.setAttribute("uv", new THREE.Float32BufferAttribute(uvs, 2));
         geometry.computeVertexNormals();
         geometry.computeFaceNormals();
-        const texture = loader.load(url);
+        const texture = texture_loader.load(url);
         texture.flipY = false;
         texture.minFilter = THREE.LinearFilter;
         const material = new THREE.MeshLambertMaterial({
@@ -188,6 +190,11 @@ Vue.component("scene", {
           const settings = { depth: height, bevelEnabled: false };
           geometry = new THREE.ExtrudeGeometry(shape, settings);
         }
+        if (type == "stl") {
+          const url = args[0];
+          geometry = new THREE.BufferGeometry();
+          stl_loader.load(url, (geometry) => (mesh.geometry = geometry));
+        }
         let material;
         if (wireframe) {
           mesh = new THREE.LineSegments(
@@ -212,6 +219,9 @@ Vue.component("scene", {
     move(object_id, x, y, z) {
       objects.get(object_id).position.set(x, y, z);
     },
+    scale(object_id, sx, sy, sz) {
+      objects.get(object_id).scale.set(sx, sy, sz);
+    },
     rotate(object_id, R) {
       const R4 = new THREE.Matrix4().makeBasis(
         new THREE.Vector3(...R[0]),
