@@ -25,7 +25,8 @@ class ValueElement(Element):
 
     def handle_change(self, msg):
         self.value = msg['value']
-        handle_event(self.change_handler, ValueChangeEventArguments(sender=self, value=self.value), update_view=True)
+        arguments = ValueChangeEventArguments(sender=self, value=self.value)
+        handle_event(self.change_handler, arguments, update=self.parent_view)
 
     def bind_value_to(self, target_object, target_name, *, forward=lambda x: x):
         bind_to(self, 'value', target_object, target_name, forward=forward)
